@@ -2,16 +2,14 @@ from __future__ import with_statement
 import pytest
 
 from redis._compat import unichr, u, unicode
-from redis.utils import HIREDIS_AVAILABLE
 from .conftest import r as _redis_client
 
 
-@pytest.fixture()
-def r(request):
-    return _redis_client(request=request, decode_responses=True)
+class TestEncoding(object):
+    @pytest.fixture()
+    def r(self, request):
+        return _redis_client(request=request, decode_responses=True)
 
-
-class BaseEncodingTests(object):
     def test_simple_encoding(self, r):
         unicode_string = unichr(3456) + u('abcd') + unichr(3421)
         r['unicode-string'] = unicode_string
@@ -26,9 +24,10 @@ class BaseEncodingTests(object):
         assert r.lrange('a', 0, -1) == result
 
 
-class TestPythonParserEncoding(BaseEncodingTests):
-    pass
+class TestCommandsAndTokensArentEncoded(object):
+    @pytest.fixture()
+    def r(self, request):
+        return _redis_client(request=request, charset='utf-16')
 
-if HIREDIS_AVAILABLE:
-    class TestHiredisParserEncoding(BaseEncodingTests):
-        pass
+    def test_basic_command(self, r):
+        r.set('hello', 'world')
